import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_iam._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_lambda_nodejs._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_s3_notifications._jsii
import aws_cdk.aws_sns._jsii
import aws_cdk.aws_sns_subscriptions._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdk-image-moderation",
    "0.1.2",
    __name__[0:-6],
    "cdk-image-moderation@0.1.2.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
